/*************************************
 Sends various messages to the server
 (c) 1999 Jeremy Wise
 GnomeICU
**************************************/

#ifndef __SENDMSG_H__
#define __SENDMSG_H__

extern int search_wait;
extern ProgressData *search_pdata;

void Do_Resend( void );
void icq_sendmsg( UIN_T uin, const gchar *text, gboolean forced );
void icq_sendurl( GtkWidget *widget, struct URLInfo *data );
void icq_sendauthmsg( UIN_T uin );
void icq_change_status( DWORD status );
void Quit_ICQ( void );
void send_info_req( UIN_T uin );
void start_search( gchar *email, gchar *nick,
		   gchar* first, gchar* last, UIN_T uin );
void send_ext_info_req( UIN_T uin );
void reg_new_user( gchar *pass );
size_t SOCKWRITE( void * ptr, size_t len, gchar *charid );
size_t SOCKREAD( void * ptr, size_t len );
void Update_User_Info( void );
void info_req_99( UIN_T uin );

#endif /* __SENDMSG_H__ */
